/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2008/12/10
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy;

import java.lang.reflect.Constructor;

import org.jiemamy.exception.IllegalImplementationException;

/**
 * Jiemamyが特定のインスタンスにアクセスする方法を示す戦略インターフェイス。
 * 
 * <p>{@link Jiemamy}がインスタンスをどのようにして取得するかは、下記の例のように利用環境に依存する。
 * このストラテジは、ファクトリ（{@link Jiemamy}）に対してインスタンスの取得する方法を与えるためのインターフェイスである。</p>
 * 
 * <ul>
 *   <li>普通に new （もしくは{@link Class#newInstance()}や {@link Constructor#newInstance(Object...)}）</li>
 *   <li>インスタンス管理を行い、キャッシュされたインスタンスを再利用するケース</li>
 *   <li>DI Containerや、その他フレームワークがインスタンスを生成し、管理するケース等</li>
 * </ul>
 * 
 * @param <T> 対象インスタンスの型
 * @since 0.2
 * @author daisuke
 */
public interface InstanceProvider<T> {
	
	/**
	* インスタンスを取得する。
	* 
	* <p>Jiemamyがインスタンスを取得する為のメソッドであり、APIユーザがコールすることは意図していない。</p>
	* 
	* @param fqcn 完全修飾クラス名
	* @return インスタンス
	* @throws ClassNotFoundException 指定した型が見つからなかった場合
	* @throws IllegalArgumentException 指定した型がT型ではなかった場合
	* @throws IllegalImplementationException 指定した型がインスタンスできない型（abstract, interface）だった場合
	* @throws IllegalImplementationException 指定した型の可視性がpublicではなかった場合
	* @since 0.2
	*/
	T getInstance(String fqcn) throws ClassNotFoundException;
	
}
