/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/03/18
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.dialect;

import java.util.ArrayList;
import java.util.Collection;

import org.jiemamy.model.datatype.BuiltinDataType;
import org.jiemamy.model.datatype.DataTypeCategory;
import org.jiemamy.model.datatype.DataTypeMold;

/**
 * {@link BuiltinDataType}インスタンスを生成する鋳型情報インターフェイス。
 * 
 * @since 0.2
 * @author daisuke
 */
public interface BuiltinDataTypeMold extends DataTypeMold<BuiltinDataType> {
	
	/** 不明なモールド */
	BuiltinDataTypeMold UNKNOWN = new BuiltinDataTypeMold() {
		
		public DataTypeCategory getCategory() {
			return DataTypeCategory.OTHER;
		}
		
		public String getName() {
			return "UNKNOWN";
		}
		
		public Collection<Class<?>> getSupportedAdapterClasses() {
			return new ArrayList<Class<?>>();
		}
	};
	

	/**
	 * データ型カテゴリを取得する。
	 * 
	 * @return データ型カテゴリ
	 * @since 0.2
	 */
	DataTypeCategory getCategory();
	
	/**
	 * 型がサポートするアダプタクラスの集合を取得する。
	 * 
	 * @return　型がサポートするアダプタクラスの集合
	 * @since 0.2
	 */
	Collection<Class<?>> getSupportedAdapterClasses();
	
}
