/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2008/08/30
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.dialect;

import java.sql.Types;
import java.util.List;

import org.jiemamy.JiemamyFactory;
import org.jiemamy.ReferenceResolver;
import org.jiemamy.model.datatype.BuiltinDataType;
import org.jiemamy.model.datatype.DataType;
import org.jiemamy.model.sql.Token;

/**
 * データ型（{@link DataType}）を中心とした各種解決を行うインターフェイス。
 * 
 * @since 0.2
 * @author daisuke
 */
public interface DataTypeResolver {
	
	/**
	 * 型記述子からデータ型をあらわすトークンシーケンスを解決する。
	 * 
	 * <p>返される{@link List}は他に影響を及ぼさない独立したインスタンスである。</p>
	 * 
	 * @param dataType 型記述子
	 * @param resolver 参照リゾルバ
	 * @return データ型をあらわすトークンシーケンス
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 * @since 0.2
	 */
	List<Token> resolveDataType(DataType dataType, ReferenceResolver resolver);
	
	/**
	 * 型名から型記述子を解決する。
	 * 
	 * <p>このメソッドは、毎回新しいインスタンスを返す。</p>
	 * 
	 * @param factory 記述子生成のためのファクトリ
	 * @param sqlType {@link Types}であらわされるデータ型
	 * @param typeName 型名
	 * @return 型記述子
	 * @throws IllegalArgumentException 引数factoryに{@code null}を与えた場合
	 * @since 0.2
	 */
	BuiltinDataType resolveDataType(JiemamyFactory factory, int sqlType, String typeName);
}
