/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/03/31
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.dialect;

import java.util.List;

import org.jiemamy.model.datatype.BuiltinDataType;
import org.jiemamy.model.datatype.DataTypeCategory;

/**
 * データ型鋳型の管理インターフェイス。
 * 
 * @author daisuke
 */
public interface MoldManager {
	
	/**
	 * 指定したデータ型に適合する、最も適したモールドを取得する。
	 * 
	 * @param builtinDataType データ型
	 * @return モールド
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 * @since 0.2
	 */
	BuiltinDataTypeMold findDataTypeMold(BuiltinDataType builtinDataType);
	
	/**
	 * 指定したカテゴリに最も適したモールドを取得する。
	 * 
	 * <p>typeNameには、{@code category.name()}を用いる。</p>
	 * 
	 * <p>{@code null}を返してはならない。</p>
	 * 
	 * @param category 型カテゴリ
	 * @return モールド
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 * @see #findDataTypeMold(DataTypeCategory, String)
	 * @since 0.2
	 */
	BuiltinDataTypeMold findDataTypeMold(DataTypeCategory category);
	
	/**
	 * 指定したカテゴリ、型名に最も適したモールドを取得する。
	 * 
	 * <p><ol>
	 *   <li>カテゴリと型名が完全一致するモールドがあれば、それを返す。</li>
	 *   <li>見つからなければ、次に、型名が完全一致するモールドがあれば、それを返す。</li>
	 *   <li>さらに見つからなければ、カテゴリが一致する中で、先に定義されているモールドを返す。</li>
	 *   <li>与えられたカテゴリに該当する型がひとつもマッピングされていない場合は、 {@link BuiltinDataTypeMold#UNKNOWN}を返す。</li>
	 * </ol></p>
	 * 
	 * <p>{@code null}を返してはならない。</p>
	 * 
	 * @param category 型カテゴリ
	 * @param typeName 型名
	 * @return モールド
	 * @throws IllegalArgumentException 引数typeNameに{@code null}を与えた場合
	 * @since 0.2
	 */
	BuiltinDataTypeMold findDataTypeMold(DataTypeCategory category, String typeName);
	
	/**
	 * 全ての鋳型のリストを取得する。
	 * 
	 * @return 全ての鋳型のリスト
	 */
	List<BuiltinDataTypeMold> getTypeList();
	
}
