/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2008/08/24
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.dialect.generic;

import java.util.Arrays;
import java.util.List;

import org.jiemamy.dialect.internal.ReservedWordsChecker;

/**
 * {@link GenericDialect}における予約語をチェックするクラス。
 * 
 * @author daisuke
 */
public class GenericReservedWords implements ReservedWordsChecker {
	
	private static final List<String> RESERVED_WORDS =
			Arrays.asList("ABSOLUTE", "ACCESS", "ACCESSIBLE", "ACCOUNT", "ACTION", "ACTIVATE", "ACTIVE", "ADA", "ADD",
					"ADMIN", "ADVISE", "AFTER", "AGGREGATE", "ALIAS", "ALL", "ALL_ROWS", "ALLOCATE", "ALLOW", "ALTER",
					"ANALYSE", "ANALYZE", "AND", "ANY", "APPLICATION", "ARCHIVE", "ARCHIVELOG", "ARE", "ARRAY", "AS",
					"ASC", "ASCENDING", "ASENSITIVE", "ASSERTION", "ASSOCIATE", "ASUTIME", "ASYMMETRIC", "AT",
					"ATTACH", "AUDIT", "AUTHENTICATED", "AUTHORIZATION", "AUTO", "AUTODDL", "AUTOEXTEND", "AUTOMATIC",
					"AUX", "AUXILIARY", "AVG", "BACKUP", "BASE_NAME", "BASED", "BASENAME", "BECOME", "BEFORE", "BEGIN",
					"BETWEEN", "BFILE", "BIGINT", "BINARY", "BIT", "BIT_LENGTH", "BITMAP", "BLOB", "BLOBEDIT", "BLOCK",
					"BODY", "BOOLEAN", "BOTH", "BOTTOM", "BREADTH", "BREAK", "BROWSE", "BUFFER", "BUFFERPOOL", "BULK",
					"BY", "CACHE", "CACHE_INSTANCES", "CALL", "CALLED", "CANCEL", "CAPABILITY", "CAPTURE",
					"CARDINALITY", "CASCADE", "CASCADED", "CASE", "CAST", "CATALOG", "CCSID", "CFILE", "CHAINED",
					"CHANGE", "CHAR", "CHAR_CONVERT", "CHAR_CS", "CHAR_LENGTH", "CHARACTER", "CHARACTER_LENGTH",
					"CHECK", "CHECK_POINT_LEN", "CHECK_POINT_LENGTH", "CHECKPOINT", "CHOOSE", "CHUNK", "CLASS",
					"CLEAR", "CLOB", "CLONE", "CLOSE", "CLOSE_CACHED_OPEN_CURSORS", "CLUSTER", "CLUSTERED", "COALESCE",
					"COLLATE", "COLLATION", "COLLECTION", "COLLID", "COLUMN", "COLUMNS", "COMMENT", "COMMIT",
					"COMMITTED", "COMPATIBILITY", "COMPILE", "COMPILETIME", "COMPLETE", "COMPLETION",
					"COMPOSITE_LIMIT", "COMPRESS", "COMPRESSED", "COMPUTE", "COMPUTED", "CONCAT", "CONDITION",
					"CONDITIONAL", "CONFLICT", "CONNECT", "CONNECT_TIME", "CONNECTION", "CONSTRAINT", "CONSTRAINTS",
					"CONSTRUCTOR", "CONTAINING", "CONTAINS", "CONTAINSTABLE", "CONTENTS", "CONTINUE", "CONTROLFILE",
					"CONVERT", "CORRESPONDING", "COST", "COUNT", "COUNT_BIG", "CPU_PER_CALL", "CPU_PER_SESSION",
					"CREATE", "CROSS", "CSTRING", "CUBE", "CURREN_USER", "CURRENT", "CURRENT_DATE", "CURRENT_LC_CTYPE",
					"CURRENT_PATH", "CURRENT_ROLE", "CURRENT_SCHEMA", "CURRENT_SERVER", "CURRENT_TIME",
					"CURRENT_TIMESTAMP", "CURRENT_TIMEZONE", "CURRENT_USER", "CURSOR", "CYCLE", "DANGLING", "DATA",
					"DATABASE", "DATABASES", "DATAFILE", "DATAFILES", "DATAOBJNO", "DATE", "DAY", "DAY_HOUR",
					"DAY_MICROSECOND", "DAY_MINUTE", "DAY_SECOND", "DAYS", "DB_KEY", "DB2GENERAL", "DB2GENRL",
					"DB2SQL", "DBA", "DBCC", "DBHIGH", "DBINFO", "DBLOW", "DBMAC", "DBSPACE", "DEALLOCATE", "DEBUG",
					"DEC", "DECIMAL", "DECLARE", "DEFAULT", "DEFAULTS", "DEFERRABLE", "DEFERRED", "DEFINITION",
					"DEGREE", "DELAYED", "DELETE", "DELETING", "DENY", "DEPTH", "DEREF", "DESC", "DESCENDING",
					"DESCRIBE", "DESCRIPTOR", "DESTROY", "DESTRUCTOR", "DETACH", "DETERMINISTIC", "DIAGNOSTICS",
					"DICTIONARY", "DIRECTORY", "DISABLE", "DISALLOW", "DISCONNECT", "DISK", "DISMOUNT", "DISPLAY",
					"DISTINCT", "DISTINCTROW", "DISTRIBUTED", "DIV", "DML", "DO", "DOMAIN", "DOUBLE", "DROP",
					"DSNHATTR", "DSSIZE", "DUAL", "DUMP", "DYNAMIC", "EACH", "ECHO", "EDIT", "EDITPROC", "ELSE",
					"ELSEIF", "ENABLE", "ENCLOSED", "ENCODING", "ENCRYPTED", "END-EXEC", "END-EXEC1", "END", "ENDEXEC",
					"ENDIF", "ENFORCE", "ENTRY", "ENTRY_POINT", "EQUALS", "ERASE", "ERRLVL", "ESCAPE", "ESCAPED",
					"EVENT", "EVERY", "EXCEPT", "EXCEPTION", "EXCEPTIONS", "EXCHANGE", "EXCLUDING", "EXCLUSIVE",
					"EXEC", "EXECUTE", "EXISTING", "EXISTS", "EXIT", "EXPIRE", "EXPLAIN", "EXTENT", "EXTENTS",
					"EXTERN", "EXTERNAL", "EXTERNALLY", "EXTERNLOGIN", "EXTRACT", "FAILED_LOGIN_ATTEMPTS", "FALSE",
					"FAST", "FENCED", "FETCH", "FIELDPROC", "FILE", "FILLFACTOR", "FILTER", "FINAL", "FIRST",
					"FIRST_ROWS", "FLAGGER", "FLOAT", "FLOAT4", "FLOAT8", "FLOB", "FLUSH", "FOR", "FORCE", "FOREIGN",
					"FORTRAN", "FORWARD", "FOUND", "FREE", "FREE_IT", "FREELIST", "FREELISTS", "FREETEXT",
					"FREETEXTTABLE", "FREEZE", "FROM", "FULL", "FULLTEXT", "FULLTEXTTABLE", "FUNCTION", "GDSCODE",
					"GEN_ID", "GENERAL", "GENERATED", "GENERATOR", "GET", "GET_CURRENT_CONNECTION", "GLOBAL",
					"GLOBAL_NAME", "GLOBALLY", "GO", "GOTO", "GRANT", "GRAPHIC", "GROUP", "GROUP_COMMIT_WAIT",
					"GROUP_COMMIT_WAIT_TIME", "GROUPING", "GROUPS", "HANDLER", "HASH", "HASHKEYS", "HAVING", "HEADER",
					"HEAP", "HELP", "HIGH_PRIORITY", "HOLD", "HOLDLOCK", "HOST", "HOUR", "HOUR_MICROSECOND",
					"HOUR_MINUTE", "HOUR_SECOND", "HOURS", "IDENTIFIED", "IDENTITY", "IDENTITY_INSERT", "IDENTITYCOL",
					"IDGENERATORS", "IDLE_TIME", "IF", "IGNORE", "ILIKE", "IMMEDIATE", "IN", "INACTIVE", "INCLUDE",
					"INCLUDING", "INCREMENT", "IND_PARTITION", "INDEX", "INDEX_LPAREN", "INDEXED", "INDEXES",
					"INDEXIN", "INDICATOR", "INFILE", "INHERIT", "INIT", "INITIAL", "INITIALIZE", "INITIALLY",
					"INITRANS", "INNER", "INNERINDEX", "INOUT", "INPUT", "INPUT_TYPE", "INSENSITIVE", "INSERT",
					"INSERTING", "INSERTINNER", "INSTALL", "INSTANCE", "INSTANCES", "INSTEAD", "INT", "INT1", "INT2",
					"INT3", "INT4", "INT8", "INTEGER", "INTEGRATED", "INTEGRITY", "INTERMEDIATE", "INTERSECT",
					"INTERSECTINSERT", "INTERVAL", "INTO", "INTOINTERSECT", "IQ", "IS", "ISINTO", "ISNULL", "ISOBID",
					"ISOLATION", "ISOLATION_LEVEL", "ISQL", "ITERATE", "JAR", "JAVA", "JOIN", "JOINIS", "KEEP",
					"KERBEROS", "KEY", "KEYJOIN", "KEYS", "KILL", "KILLKEY", "LABEL", "LANGUAGE", "LARGE", "LAST",
					"LATERAL", "LAYER", "LC_CTYPE", "LC_MESSAGES", "LC_TYPE", "LEADING", "LEAVE", "LEFT", "LEFTKILL",
					"LENGTH", "LESS", "LEV", "LEVEL", "LIBRARY", "LIKE", "LIKELEFT", "LIMIT", "LINEAR", "LINENOLIKE",
					"LINES", "LINK", "LINKTYPE", "LIST", "LOAD", "LOADLINENO", "LOB", "LOCAL", "LOCALE", "LOCALTIME",
					"LOCALTIMESTAMP", "LOCATOR", "LOCATORS", "LOCK", "LOCKED", "LOCKMAX", "LOCKSIZE", "LOG",
					"LOG_BUF_SIZE", "LOG_BUFFER_SIZE", "LOGFILE", "LOGGING", "LOGICAL_READS_PER_CALL",
					"LOGICAL_READS_PER_SESSION", "LOGIN", "LONG", "LONGBLOB", "LONGINT", "LONGTEXT", "LOOP",
					"LOW_PRIORITY", "LOWER", "LTRIM", "MANAGE", "MANUAL", "MAP", "MASTER",
					"MASTER_SSL_VERIFY_SERVER_CERT", "MATCH", "MAX", "MAX_SEGMENT", "MAXARCHLOGS", "MAXDATAFILES",
					"MAXEXTENTS", "MAXIMUM", "MAXIMUM_SEGMENT", "MAXINSTANCES", "MAXLOGFILES", "MAXLOGHISTORY",
					"MAXLOGMEMBERS", "MAXSIZE", "MAXTRANS", "MAXVALUE", "MEDIUMBLOB", "MEDIUMINT", "MEDIUMTEXT",
					"MEMBER", "MEMBERSHIP", "MERGE", "MESSAGE", "MICROSECOND", "MICROSECONDS", "MIDDLEINT", "MIN",
					"MINEXTENTS", "MINIMUM", "MINUS", "MINUTE", "MINUTE_MICROSECOND", "MINUTE_SECOND", "MINUTES",
					"MINVALUE", "MLS_LABEL_FORMAT", "MLSLABEL", "MOD", "MODE", "MODIFIES", "MODIFY", "MODULE",
					"MODULE_NAME", "MONTH", "MONTHS", "MOUNT", "MOVE", "MTS_DISPATCHERS", "MULTISET", "NAMES",
					"NATIONAL", "NATIONALLOAD", "NATURAL", "NCHAR", "NCHAR_CS", "NCLOB", "NEEDED", "NESTED", "NETWORK",
					"NEW", "NEW_TABLE", "NEXT", "NO", "NO_WRITE_TO_BINLOG", "NOARCHIVELOG", "NOAUDIT", "NOAUTO",
					"NOCACHE", "NOCHECKNATIONAL", "NOCOMPRESS", "NOCYCLE", "NODENAME", "NODENUMBER", "NOFORCE",
					"NOHOLDLOCK", "NOLOGGING", "NOMAXVALUE", "NOMINVALUE", "NONCLUSTEREDNOCHECK", "NONE", "NOORDER",
					"NOOVERRIDE", "NOPARALLEL", "NOREVERSE", "NORMAL", "NOSORT", "NOT", "NOTHING", "NOTIFY",
					"NOTNONCLUSTERED", "NOTNULL", "NOWAIT", "NULL", "NULLIF", "NULLIFNULL", "NULLNOT", "NULLS",
					"NUM_LOG_BUFFERS", "NUM_LOG_BUFS", "NUMBER", "NUMERIC", "NUMPARTS", "NVARCHAR", "NVARCHAR2",
					"OBID", "OBJECT", "OBJNO", "OBJNO_REUSE", "OCTET_LENGTH", "OF", "OFF", "OFFLINE", "OFFOF",
					"OFFSET", "OFFSETSOFF", "OFNULLIF", "OID", "OIDINDEX", "OLD", "OLD_TABLE", "ON", "ONLINE", "ONLY",
					"ONOFFSETS", "OPCODE", "OPEN", "OPENDATASOURCEOPEN", "OPENON", "OPENQUERYOPENDATASOURCE",
					"OPENROWSETOPENQUERY", "OPENXMLOPENROWSET", "OPERATION", "OPTIMAL", "OPTIMIZATION", "OPTIMIZE",
					"OPTIMIZER_GOAL", "OPTION", "OPTIONALLY", "OPTIONOPENXML", "OPTIONS", "OR", "ORDER", "ORDEROR",
					"ORDINALITY", "ORGANIZATION", "OROPTION", "OSLABEL", "OTHERS", "OUT", "OUTER", "OUTERORDER",
					"OUTFILE", "OUTPUT", "OUTPUT_TYPE", "OVER", "OVERFLOW", "OVERLAPS", "OVEROUTER", "OVERRIDING",
					"OWN", "PACKAGE", "PAD", "PAGE", "PAGE_SIZE", "PAGELENGTH", "PAGES", "PARALLEL", "PARAMETER",
					"PARAMETERS", "PART", "PARTIAL", "PARTITION", "PASCAL", "PASSTHROUGH", "PASSWORD",
					"PASSWORD_GRACE_TIME", "PASSWORD_LIFE_TIME", "PASSWORD_LOCK_TIME", "PASSWORD_REUSE_MAX",
					"PASSWORD_REUSE_TIME", "PASSWORD_VERIFY_FUNCTION", "PATH", "PCTFREE", "PCTINCREASE",
					"PCTTHRESHOLD", "PCTUSED", "PCTVERSION", "PERCENT", "PERCENTOVER", "PERMANENT", "PIECESIZE",
					"PIVOTPERCENT", "PLACING", "PLAN", "PLANPIVOT", "PLANPRECISION", "PLSQL_DEBUG", "POSITION",
					"POST_EVENT", "POST_TRANSACTION", "POSTFIX", "PRECISION", "PREFIX", "PREORDER", "PREPARE",
					"PRESERVE", "PRIMARY", "PRINT", "PRIOR", "PRIQTY", "PRIVATE", "PRIVATE_SGA", "PRIVILEGE",
					"PRIVILEGES", "PROC", "PROCEDURE", "PROFILE", "PROGRAM", "PSID", "PUBLIC", "PUBLICATION", "PURGE",
					"QUERYNO", "QUEUE", "QUIT", "QUOTA", "RAISERROR", "RANGE", "RAW", "RAW_PARTITIONS", "RBA",
					"RDB$DB_KEY", "READ", "READ_ONLY", "READ_WRITE", "READS", "READTEXT", "READUP", "REAL", "REBUILD",
					"RECONFIGURE", "RECORD_VERSION", "RECOVER", "RECOVERABLE", "RECOVERY", "RECURSIVE", "REF",
					"REFERENCE", "REFERENCES", "REFERENCING", "REFRESH", "REGEXP", "RELATIVE", "RELEASE", "REMOTE",
					"REMOVE", "RENAME", "REORGANIZE", "REPEAT", "REPLACE", "REPLICATION", "REQUIRE", "RESERV",
					"RESERVING", "RESET", "RESETLOGS", "RESIGNAL", "RESIZE", "RESOURCE", "RESTART", "RESTORE",
					"RESTRICT", "RESTRICTED", "RESULT", "RESULT_SET_LOCATOR", "RETAIN", "RETURN", "RETURNING",
					"RETURNING_VALUES", "RETURNS", "REUSE", "REVERSE", "REVERT", "REVOKE", "RIGHT", "RLIKE", "ROLE",
					"ROLES", "ROLLBACK", "ROLLUP", "ROUTINE", "ROW", "ROWCOUNT", "ROWGUIDCOL", "ROWID", "ROWNUM",
					"ROWS", "RRN", "RTRIM", "RULE", "RUN", "RUNTIME", "RUNTIMESTATISTICS", "SAMPLE", "SAVE",
					"SAVEPOINT", "SB4", "SCAN_INSTANCES", "SCHEMA", "SCHEMAS", "SCN", "SCOPE", "SCRATCHPAD", "SCROLL",
					"SD_ALL", "SD_INHIBIT", "SD_SHOW", "SEARCH", "SECOND", "SECOND_MICROSECOND", "SECONDS", "SECQTY",
					"SECTION", "SECURITY", "SECURITYAUDIT", "SEG_BLOCK", "SEG_FILE", "SEGMENT", "SELECT", "SENSITIVE",
					"SEPARATOR", "SEQUENCE", "SERIALIZABLE", "SESSION", "SESSION_CACHED_CURSORS", "SESSION_USER",
					"SESSIONS_PER_USER", "SET", "SETS", "SETUSER", "SHADOW", "SHARE", "SHARED", "SHARED_POOL", "SHELL",
					"SHOW", "SHRINK", "SHUTDOWN", "SIGNAL", "SIMILAR", "SIMPLE", "SINGULAR", "SIZE", "SKIP",
					"SKIP_UNUSABLE_INDEXES", "SMALLINT", "SNAPSHOT", "SOME", "SORT", "SOURCE", "SPACE", "SPATIAL",
					"SPECIFIC", "SPECIFICATION", "SPECIFICTYPE", "SPLIT", "SQL", "SQL_BIG_RESULT",
					"SQL_CALC_FOUND_ROWS", "SQL_SMALL_RESULT", "SQL_TRACE", "SQLCA", "SQLCODE", "SQLERROR",
					"SQLEXCEPTION", "SQLID", "SQLSTATE", "SQLWARNING", "SSL", "STABILITY", "STANDARD", "STANDBY",
					"START", "STARTING", "STARTS", "STATE", "STATEMENT", "STATEMENT_ID", "STATIC", "STATISTICS",
					"STAY", "STOGROUP", "STOP", "STORAGE", "STORE", "STORES", "STRAIGHT_JOIN", "STRUCTURE", "STYLE",
					"SUB_TYPE", "SUBPAGES", "SUBSTR", "SUBSTRING", "SUBTRANS", "SUBTRANSACTION", "SUCCESSFUL", "SUM",
					"SUSPEND", "SWITCH", "SYMMETRIC", "SYNCHRONIZE", "SYNONYM", "SYNTAX_ERROR",
					"SYS_OP_ENFORCE_NOT_NULL$", "SYS_OP_NTCIMG$", "SYSDATE", "SYSDBA", "SYSFUN", "SYSIBM", "SYSOPER",
					"SYSPROC", "SYSTEM", "SYSTEM_USER", "SYSTIME,", "SYSTIMESTAMP", "TABLE", "TABLES", "TABLESAMPLE",
					"TABLESPACE", "TABLESPACE_NO", "TABNO", "TEMPORARY", "TERMINATE", "TERMINATED", "TERMINATOR",
					"TEXTSIZE", "THAN", "THE", "THEN", "THREAD", "TIME", "TIMESTAMP", "TIMEZONE_HOUR",
					"TIMEZONE_MINUTE", "TINYBLOB", "TINYINT", "TINYTEXT", "TO", "TODAY", "TOP", "TOPLEVEL", "TRACE",
					"TRACING", "TRAILING", "TRAN", "TRANSACTION", "TRANSITIONAL", "TRANSLATE", "TRANSLATION", "TREAT",
					"TRIGGER", "TRIGGERS", "TRIM", "TRUE", "TRUNCATE", "TSEQUAL", "TX", "TYPE", "UB2", "UBA", "UID",
					"UNARCHIVED", "UNBOUNDED", "UNCOMMITTED", "UNDER", "UNDO", "UNION", "UNIQUE", "UNIQUEIDENTIFIER",
					"UNKNOWN", "UNLIMITED", "UNLOCK", "UNNEST", "UNPIVOT", "UNRECOVERABLE", "UNSIGNED", "UNTIL",
					"UNUSABLE", "UNUSED", "UPDATABLE", "UPDATE", "UPDATETEXT", "UPDATING", "UPPER", "USAGE", "USE",
					"USER", "USING", "UTC_DATE", "UTC_TIME", "UTC_TIMESTAMP", "VALIDATE", "VALIDATION", "VALIDPROC",
					"VALUE", "VALUES", "VARBINARY", "VARBIT", "VARCHAR", "VARCHAR2", "VARCHARACTER", "VARIABLE",
					"VARIANT", "VARYING", "VCAT", "VERBOSE", "VERSION", "VIEW", "VOLUMES", "WAIT", "WAITFOR",
					"WEEKDAY", "WHEN", "WHENEVER", "WHERE", "WHILE", "WINDOW", "WITH", "WITH_CUBE", "WITH_LPAREN",
					"WITH_ROLLUP", "WITHIN", "WITHOUT", "WLM", "WORK", "WRITE", "WRITEDOWN", "WRITETEXT", "WRITEUP",
					"X509", "XID", "XML", "XOR", "YEAR", "YEAR_MONTH", "YEARDAY", "YEARS", "ZEROFILL", "ZONE");
	

	public boolean isReserved(String name) {
		return RESERVED_WORDS.contains(name);
	}
	
}
