/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/03/30
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.dialect.internal.impl;

import java.util.Map;

import org.apache.commons.lang.Validate;

import org.jiemamy.JiemamyFactory;
import org.jiemamy.dialect.internal.ForeignKeyImportVisitor;
import org.jiemamy.model.RootModel;
import org.jiemamy.model.attribute.ColumnModel;
import org.jiemamy.model.attribute.constraint.Deferrability;
import org.jiemamy.model.attribute.constraint.ForeignKey;
import org.jiemamy.model.attribute.constraint.Deferrability.InitiallyCheckTime;
import org.jiemamy.model.attribute.constraint.ForeignKey.ReferentialAction;
import org.jiemamy.model.entity.TableModel;
import org.jiemamy.utils.metadata.KeyMeta;
import org.jiemamy.utils.model.ForeignKeyUtil;
import org.jiemamy.utils.visitor.AbstractCollectionVisitor;

/**
 * {@link ForeignKeyImportVisitor}のデフォルト実装クラス。
 * 
 * @author daisuke
 */
public class DefaultForeignKeyImportVisitor extends AbstractCollectionVisitor<KeyMeta, Void, RuntimeException>
		implements ForeignKeyImportVisitor {
	
	/** 書き込み先モデル */
	private RootModel rootModel;
	
	private Map<String, ForeignKey> importedForeignKeys;
	

	public void initialize(RootModel rootModel, Map<String, ForeignKey> importedForeignKeys) {
		Validate.notNull(rootModel);
		Validate.notNull(importedForeignKeys);
		this.rootModel = rootModel;
		this.importedForeignKeys = importedForeignKeys;
	}
	
	public Void visit(KeyMeta keys) {
		Validate.notNull(keys);
		TableModel constrainedTable = rootModel.getEntity(TableModel.class, keys.fkTableName);
		TableModel referenceTable = rootModel.getEntity(TableModel.class, keys.pkTableName);
		
		if (constrainedTable != null && referenceTable != null) {
			JiemamyFactory factory = rootModel.getJiemamy().getFactory();
			ForeignKey foreignKey = importedForeignKeys.get(keys.fkName);
			if (foreignKey == null) {
				foreignKey = factory.newModel(ForeignKey.class);
				foreignKey.setName(keys.fkName);
				constrainedTable.getAttributes().add(foreignKey);
				importedForeignKeys.put(keys.fkName, foreignKey);
			}
			ColumnModel fkColumn = constrainedTable.findColumn(keys.fkColumnName);
			ColumnModel pkColumn = referenceTable.findColumn(keys.pkColumnName);
			ForeignKeyUtil.addMapping(foreignKey, fkColumn, pkColumn);
			
			if (keys.updateRule != null) {
				ReferentialAction onUpdate = ReferentialAction.valueOf(keys.updateRule.name());
				foreignKey.setOnUpdate(onUpdate);
			}
			
			if (keys.deleteRule != null) {
				ReferentialAction onDelete = ReferentialAction.valueOf(keys.deleteRule.name());
				foreignKey.setOnDelete(onDelete);
			}
			
			Deferrability deferrability;
			switch (keys.deferrability) {
				case INITIALLY_DEFERRED:
					deferrability = factory.newModel(Deferrability.class);
					deferrability.setDeferrable(true);
					deferrability.setInitiallyCheckTime(InitiallyCheckTime.DEFERRED);
					break;
				
				case INITIALLY_IMMEDIATE:
					deferrability = factory.newModel(Deferrability.class);
					deferrability.setDeferrable(true);
					deferrability.setInitiallyCheckTime(InitiallyCheckTime.IMMEDIATE);
					break;
				
				case NOT_DEFERRABLE:
					deferrability = factory.newModel(Deferrability.class);
					deferrability.setDeferrable(false);
					break;
				
				default:
					deferrability = null;
					break;
			}
			foreignKey.setDeferrability(deferrability);
		}
		return null;
	}
}
