/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2008/12/24
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.internal.builder;

import org.apache.commons.lang.Validate;

import org.jiemamy.JiemamyFactory;
import org.jiemamy.experimental.builder.JiemamyBuilder;
import org.jiemamy.model.JiemamyElement;
import org.jiemamy.model.RootModel;

/**
 * {@link JiemamyElement}を構築するためのビルダー骨格実装抽象クラス。
 * 
 * @param <T> 構築するモデルの型
 * @author daisuke
 */
public abstract class AbstractJiemamyBuilder<T extends JiemamyElement> implements JiemamyBuilder<T> {
	
	/** 構築元となる{@link JiemamyFactory} */
	JiemamyFactory factory;
	
	/** 構築対象モデル */
	T model;
	
	private boolean finished;
	

	/**
	 * インスタンスを生成する。
	 * 
	 * @param factory 構築元となる{@link RootModel}
	 * @param clazz 構築するオブジェクトを表す型
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public AbstractJiemamyBuilder(JiemamyFactory factory, Class<T> clazz) {
		Validate.notNull(factory);
		Validate.notNull(clazz);
		this.factory = factory;
		model = factory.newModel(clazz);
	}
	
	public T build() {
		return build(false);
	}
	
	public T build(boolean force) {
		if (finished) {
			throw new IllegalStateException("This builder is already disposed.");
		}
		finished = true;
		if (force == false && isComplete() == false) {
			throw new IllegalStateException("Required operation is not performed.");
		}
		return model;
	}
	
	abstract boolean isComplete();
}
