/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2008/12/24
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.internal.builder;

import org.apache.commons.lang.Validate;

import org.jiemamy.JiemamyFactory;
import org.jiemamy.experimental.builder.ColumnBuilder;
import org.jiemamy.model.attribute.ColumnModel;
import org.jiemamy.model.attribute.constraint.ColumnConstraint;
import org.jiemamy.model.attribute.constraint.ConstraintModel;
import org.jiemamy.model.datatype.DataType;

/**
 * {@link ColumnModel}を構築するためのビルダー実装クラス。
 * 
 * @author daisuke
 */
public class ColumnBuilderImpl extends AbstractJiemamyBuilder<ColumnModel> implements ColumnBuilder {
	
	/**
	 * インスタンスを生成する。
	 * 
	 * @param factory モデル生成のためのファクトリ
	 */
	public ColumnBuilderImpl(JiemamyFactory factory) {
		super(factory, ColumnModel.class);
	}
	
	/**
	 * インスタンスを生成する。
	 * 
	 * @param factory モデル生成のためのファクトリ
	 * @param name カラム名
	 * @param type 型記述子
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public ColumnBuilderImpl(JiemamyFactory factory, String name, DataType type) {
		super(factory, ColumnModel.class);
		Validate.notNull(name);
		Validate.notNull(type);
		model.setName(name);
		model.setDataType(type);
	}
	
	/**
	 * 制約モデルを生成する。
	 * 
	 * @param clazz 制約モデルの型
	 * @return 制約モデル
	 */
	protected ConstraintModel newConstraint(Class<? extends ColumnConstraint> clazz) {
		return factory.newModel(clazz);
	}
	
	@Override
	boolean isComplete() {
		return model.getName() != null && model.getDataType() != null;
	}
}
