/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/02/28
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.internal.model;

import java.util.List;
import java.util.UUID;

import org.apache.commons.lang.Validate;

import org.jiemamy.Jiemamy;
import org.jiemamy.model.ConnectionProfile;
import org.jiemamy.model.geometory.JmColor;
import org.jiemamy.model.geometory.JmPoint;
import org.jiemamy.utils.ValidateUtil;

/**
 * {@link ConnectionProfile}の実装クラス。
 * 
 * @author daisuke
 */
public class ConnectionProfileImpl extends AbstractJiemamyElement implements ConnectionProfile {
	
	/** コネクションの色情報 */
	private JmColor color;
	
	/** ベンドポイントのリスト */
	private List<JmPoint> bendpoints;
	

	/**
	 * インスタンスを生成する。
	 * 
	 * @param jiemamy コンテキスト
	 * @param id モデルID
	 */
	public ConnectionProfileImpl(Jiemamy jiemamy, UUID id) {
		super(jiemamy, id);
	}
	
	public List<JmPoint> getBendpoints() {
		return bendpoints;
	}
	
	public JmColor getColor() {
		return color;
	}
	
	/**
	 * ベンドポイントのリストを設定する。
	 * 
	 * @param bendpoints ベンドポイントのリスト
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public void setBendpoints(List<JmPoint> bendpoints) {
		Validate.notNull(bendpoints);
		ValidateUtil.injectionSetter(this.bendpoints);
		this.bendpoints = bendpoints;
	}
	
	public void setColor(JmColor color) {
		this.color = color;
	}
}
