/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2008/06/09
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.internal.model;

import java.util.Map;
import java.util.UUID;

import org.apache.commons.lang.Validate;

import org.jiemamy.Jiemamy;
import org.jiemamy.model.ConnectionProfile;
import org.jiemamy.model.DiagramPresentationModel;
import org.jiemamy.model.Level;
import org.jiemamy.model.Mode;
import org.jiemamy.model.NodeProfile;
import org.jiemamy.model.connection.ConnectionAdapter;
import org.jiemamy.model.node.NodeAdapter;
import org.jiemamy.utils.ValidateUtil;

/**
 * ダイアグラム表現（レイアウト等）モデル。
 * 
 * @author daisuke
 */
public class DiagramPresentationModelImpl extends AbstractJiemamyElement implements DiagramPresentationModel {
	
	/** プレゼンテーション名 */
	private String name;
	
	/**
	 * ノードのレイアウト情報
	 * 
	 * 表示されるノードであれば矩形情報を持ち、非表示であればエントリを持たない。
	 */
	private Map<NodeAdapter, NodeProfile> nodeProfiles;
	
	/**
	 * コネクションのベンドポイント情報
	 * 
	 * ベンドポイントがあれば座標のリストを持ち、なければエントリを持たない。
	 */
	private Map<ConnectionAdapter, ConnectionProfile> connectionProfiles;
	
	/** 論理モデルかどうか */
	private Mode mode = Mode.PHYSICAL;
	
	/** 表示レベル */
	private Level level = Level.ATTRTYPE;
	

	/**
	 * インスタンスを生成する。
	 * 
	 * @param jiemamy コンテキスト
	 * @param id モデルID
	 */
	public DiagramPresentationModelImpl(Jiemamy jiemamy, UUID id) {
		super(jiemamy, id);
	}
	
	public Map<ConnectionAdapter, ConnectionProfile> getConnectionProfiles() {
		assert connectionProfiles != null;
		return connectionProfiles;
	}
	
	public Level getLevel() {
		return level;
	}
	
	public Mode getMode() {
		return mode;
	}
	
	public String getName() {
		return name;
	}
	
	public Map<NodeAdapter, NodeProfile> getNodeProfiles() {
		assert nodeProfiles != null;
		return nodeProfiles;
	}
	
	/**
	 * コネクションのベンドポイント情報を設定する。
	 * 
	 * @param connectionProfiles コネクションのベンドポイント情報
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public void setConnectionProfiles(Map<ConnectionAdapter, ConnectionProfile> connectionProfiles) {
		Validate.notNull(connectionProfiles);
		ValidateUtil.injectionSetter(this.connectionProfiles);
		this.connectionProfiles = connectionProfiles;
	}
	
	public void setLevel(Level level) {
		Validate.notNull(mode);
		this.level = level;
	}
	
	public void setMode(Mode mode) {
		Validate.notNull(mode);
		this.mode = mode;
	}
	
	public void setName(String name) {
		this.name = name;
	}
	
	/**
	 * ノードのレイアウト情報を設定する。
	 * 
	 * @param nodeProfiles ノードのレイアウト情報
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public void setNodeProfiles(Map<NodeAdapter, NodeProfile> nodeProfiles) {
		Validate.notNull(nodeProfiles);
		ValidateUtil.injectionSetter(this.nodeProfiles);
		this.nodeProfiles = nodeProfiles;
	}
}
