/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2008/06/09
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.internal.model.connection;

import java.util.List;

import org.apache.commons.lang.Validate;

import org.jiemamy.exception.ModelConsistenceException;
import org.jiemamy.model.attribute.ColumnModel;
import org.jiemamy.model.attribute.ColumnRef;
import org.jiemamy.model.attribute.constraint.ForeignKey;
import org.jiemamy.model.connection.ConnectionAdapter;
import org.jiemamy.model.entity.TableModel;
import org.jiemamy.model.node.NodeAdapter;

/**
 * コネクション（FKと継承等）の抽象クラス。
 * 
 * @author daisuke
 */
public class ConnectionAdapterImpl implements ConnectionAdapter {
	
	private final ForeignKey coreForeignKey;
	

	/**
	 * インスタンスを生成する。
	 * 
	 * @param coreForeignKey コネクションの基礎となる外部キー
	 * @throws IllegalArgumentException 引数jiemamyまたはidに{@code null}を与えた場合
	 */
	public ConnectionAdapterImpl(ForeignKey coreForeignKey) {
		Validate.notNull(coreForeignKey);
		this.coreForeignKey = coreForeignKey;
	}
	
	public NodeAdapter getSource() {
		List<ColumnRef> keyColumns = coreForeignKey.getKeyColumns();
		if (keyColumns.size() == 0) {
			throw new ModelConsistenceException("foreignKey has no key columns");
		}
		ColumnRef columnRef = keyColumns.get(0);
		ColumnModel columnModel = columnRef.getJiemamy().getReferenceResolver().resolve(columnRef);
		TableModel definedTable = columnModel.findDeclaringTable();
		if (definedTable == null) {
			return null;
		}
		return definedTable.getAdapter(NodeAdapter.class);
	}
	
	public NodeAdapter getTarget() {
		List<ColumnRef> referenceColumns = coreForeignKey.getReferenceColumns();
		if (referenceColumns.size() == 0) {
			throw new ModelConsistenceException("foreignKey has no reference columns");
		}
		ColumnRef columnRef = referenceColumns.get(0);
		ColumnModel columnModel = columnRef.getJiemamy().getReferenceResolver().resolve(columnRef);
		TableModel definedTable = columnModel.findDeclaringTable();
		if (definedTable == null) {
			return null;
		}
		return definedTable.getAdapter(NodeAdapter.class);
	}
	
	public boolean isSelfConnection() {
		return getSource().equals(getTarget());
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("ConnectionAdapter(S=");
		sb.append(coreForeignKey.getKeyColumns().size() > 0 ? getSource() : "UNKNOWN");
		sb.append(", T=");
		sb.append(coreForeignKey.getReferenceColumns().size() > 0 ? getTarget() : "UNKNOWN");
		sb.append(")");
		return sb.toString();
//		return ToStringBuilder.reflectionToString(this, ToStringStyle.SHORT_PREFIX_STYLE);
	}
	
	public ForeignKey unwrap() {
		return coreForeignKey;
	}
}
