/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/01/19
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.internal.model.datatype;

import java.util.UUID;

import org.apache.commons.lang.Validate;

import org.jiemamy.Jiemamy;
import org.jiemamy.ReferenceResolver;
import org.jiemamy.internal.model.AbstractElementReference;
import org.jiemamy.model.datatype.BuiltinDataType;
import org.jiemamy.model.datatype.DomainModel;
import org.jiemamy.model.datatype.DomainRef;

/**
 * {@link DomainModel}に対する参照オブジェクトの実装。Artemisにおける{@link DomainRef}の実装クラス。
 * 
 * @author daisuke
 */
public class DomainRefImpl extends AbstractElementReference<DomainModel> implements DomainRef {
	
	/**
	 * インスタンスを生成する。
	 * 
	 * @param decl 定義オブジェクト
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public DomainRefImpl(DomainModel decl) {
		super(decl);
	}
	
	/**
	 * インスタンスを生成する。
	 * 
	 * @param jiemamy コンテキスト
	 * @param referenceId 参照先のモデルID
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public DomainRefImpl(Jiemamy jiemamy, UUID referenceId) {
		super(jiemamy, referenceId);
	}
	
	public BuiltinDataType toBuiltinDataType(ReferenceResolver resolver) {
		Validate.notNull(resolver);
		
		DomainModel domainModel = resolver.resolve(this);
		return domainModel.getDataType();
	}
	
}
