/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2008/06/09
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.internal.model.node;

import java.util.List;
import java.util.UUID;

import org.apache.commons.collections15.ListUtils;

import org.jiemamy.Jiemamy;
import org.jiemamy.internal.model.AbstractJiemamyElement;
import org.jiemamy.model.connection.ConnectionAdapter;
import org.jiemamy.model.entity.EntityModel;
import org.jiemamy.model.node.NodeAdapter;
import org.jiemamy.model.node.StickyModel;

/**
 * 付箋モデル。
 * 
 * @author daisuke
 */
public class StickyModelImpl extends AbstractJiemamyElement implements StickyModel {
	
	/** 内容文 */
	private String contents;
	

	/**
	 * インスタンスを生成する。
	 * 
	 * @param jiemamy コンテキスト
	 * @param id モデルID
	 */
	public StickyModelImpl(Jiemamy jiemamy, UUID id) {
		super(jiemamy, id);
	}
	
	public int compareTo(NodeAdapter o) {
		if (o == null) {
			return -1;
		}
		if (getClass() != o.getClass()) {
			return this.getClass().getName().compareTo(o.getClass().getName());
		}
		return getId().compareTo(((StickyModelImpl) o).getId());
	}
	
	public String getContents() {
		return contents;
	}
	
	@SuppressWarnings("unchecked")
	public List<ConnectionAdapter> getSourceConnections() {
		// 現状で、Stickyはコネクションを持たない
		return ListUtils.EMPTY_LIST;
	}
	
	@SuppressWarnings("unchecked")
	public List<ConnectionAdapter> getTargetConnections() {
		// 現状で、Stickyはコネクションを持たない
		return ListUtils.EMPTY_LIST;
	}
	
	public void setContents(String contents) {
		this.contents = contents;
	}
	
	public EntityModel unwrap() {
		return null;
	}
}
