/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2008/09/17
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.model.connection;

import org.jiemamy.exception.ModelConsistenceException;
import org.jiemamy.model.Adapter;
import org.jiemamy.model.AdapterType;
import org.jiemamy.model.attribute.constraint.ForeignKey;
import org.jiemamy.model.node.NodeAdapter;

/**
 * ダイアグラムにおける「結合」を表すアダプタインターフェイス。
 * 
 * @since 0.2
 * @author daisuke
 */
@Adapter(AdapterType.LOGIC)
public interface ConnectionAdapter {
	
	/**
	 * 接続元ノードを取得する。
	 * 
	 * @return 接続元ノード
	 * @throws ModelConsistenceException モデルの不整合により、接続元ノードが不明な場合
	 * @since 0.2
	 */
	NodeAdapter getSource();
	
	/**
	 * 接続先ノードを取得する。 
	 * 
	 * @return 接続先ノード
	 * @throws ModelConsistenceException モデルの不整合により、接続先ノードが不明な場合
	 * @since 0.2
	 */
	NodeAdapter getTarget();
	
	/**
	 * 自分同士を繋ぐコネクションであるかどうかを調べる。
	 * 
	 * @return 自己コネクションである場合は{@code true}、そうでない場合は{@code false}
	 * @since 0.2
	 */
	boolean isSelfConnection();
	
	/**
	 * このオブジェクトでラッピングされた、コアオブジェクトを取得する。
	 * 
	 * @return コアとなっている外部キー
	 * @since 0.2
	 */
	ForeignKey unwrap();
}
