/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/02/26
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.utils;

/**
 * {@link Adaptable#getAdapter(Class)}により、登録されていないアダプタを取得しようとした場合。
 * 
 * @since 0.2
 * @author daisuke
 */
@SuppressWarnings("serial")
public class AdapterNotFoundException extends RuntimeException {
	
	/** 見つけられなかったアダプタの型 */
	private final Class<?> adapterClass;
	

	/**
	 * インスタンスを生成する。
	 * 
	 * @param adapterClass 見つけられなかったアダプタの型
	 * @since 0.2
	 */
	public AdapterNotFoundException(Class<?> adapterClass) {
		super(adapterClass.getName());
		this.adapterClass = adapterClass;
	}
	
	/**
	 * 見つけられなかったアダプタの型を取得する。
	 * 
	 * @return 見つけられなかったアダプタの型
	 * @since 0.2
	 */
	public Class<?> getAdapterClass() {
		return adapterClass;
	}
	
}
