/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2008/09/10
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.utils;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang.Validate;

import org.jiemamy.exception.UnexpectedConditionError;
import org.jiemamy.model.RootModel;
import org.jiemamy.model.entity.EntityModel;

/**
 * エンティティの依存度を計算するクラス。
 * 
 * @author daisuke
 */
public final class EntityDependencyCalculator {
	
	/** 並べ替えの結果 */
	private static List<EntityModel> results;
	

	/**
	 * エンティティを、依存度の低い順に並べ替えたリストを取得します。
	 * 
	 * @param rootModel 対象のデータベースモデル
	 * @return エンティティのリスト
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public static List<EntityModel> getSortedEntityList(RootModel rootModel) {
		Validate.notNull(rootModel);
		
		results = new ArrayList<EntityModel>(rootModel.getEntities().size());
		
		for (EntityModel entityModel : rootModel.getEntities()) {
			addDependsdentsToResult(entityModel);
			addToResult(entityModel);
		}
		
		return results;
	}
	
	/**
	 * 対象に依存するentityを結果に追加します。
	 * 
	 * @param entityModel 依存調査対象となるentity
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	private static void addDependsdentsToResult(EntityModel entityModel) {
		Validate.notNull(entityModel);
		
		for (EntityModel dependent : entityModel.findSuperEntities(false)) {
			if (dependent.equals(entityModel) == false) {
				addDependsdentsToResult(dependent);
				addToResult(dependent);
			}
		}
	}
	
	/**
	 * entityを結果に追加します。 但し、既に結果に含まれていた場合は何もしない。
	 * 
	 * @param entityModel 追加するentity
	 */
	private static void addToResult(EntityModel entityModel) {
		assert results != null;
		if (results.contains(entityModel) == false) {
			results.add(entityModel);
		}
	}
	
	private EntityDependencyCalculator() {
		throw new UnexpectedConditionError("不到達ポイント");
	}
}
