/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/01/21
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.utils;

import java.text.MessageFormat;
import java.util.Arrays;
import java.util.Locale;
import java.util.Map;

import org.apache.commons.lang.Validate;

/**
 * 国際化メッセージを管理するクラス。
 * 
 * @author daisuke
 */
public class LocalizedMessages {
	
	private Map<Locale, String> messages = CollectionsUtil.newHashMap();
	

	/**
	 * ロケールに従ったメッセージを取得する。
	 * 
	 * @param localeIndication ロケール指示
	 * @param argments メッセージ引数
	 * @return メッセージ
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public String getMessage(Locale localeIndication, Object[] argments) {
		Validate.notNull(localeIndication);
		Validate.notNull(argments);
		String message = null;
		Locale locale = null;
		for (Locale loc : Arrays.asList(localeIndication, Locale.getDefault(), Locale.US)) {
			message = messages.get(loc);
			if (message != null) {
				locale = loc;
				break;
			}
		}
		
		if (message == null) {
			message = "";
		}
		
		if (locale == null) {
			locale = Locale.getDefault();
		}
		
		return new MessageFormat(message, locale).format(argments);
	}
	
	/**
	 * メッセージを登録する。
	 * 
	 * @param locale ロケール
	 * @param pattern メッセージフォーマット
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public void register(Locale locale, String pattern) {
		Validate.notNull(locale);
		Validate.notNull(pattern);
		messages.put(locale, pattern);
	}
	
}
