/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/04/08
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.utils;

import java.util.Collection;

import org.apache.commons.lang.Validate;

import org.jiemamy.validator.Problem;
import org.jiemamy.validator.Validator;
import org.jiemamy.validator.Problem.Severity;

/**
 * {@link Validator}のユーティリティクラス。
 * 
 * @author daisuke
 */
public final class ValidatorUtil {
	
	/**
	 * 指定した問題の重要度<b>以上</b>（指定した問題の重要度を含む）の問題数を取得する。
	 * 
	 * @param problems 問題の集合
	 * @param severity 問題の重要度
	 * @return 指定した問題の重要度<b>以上</b>の問題数
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public static int sizeOf(Collection<Problem> problems, Severity severity) {
		Validate.notNull(problems);
		Validate.notNull(severity);
		int count = 0;
		for (Problem problem : problems) {
			if (problem.getSeverity().ordinal() <= severity.ordinal()) {
				count++;
			}
		}
		return count;
	}
	
	private ValidatorUtil() {
	}
}
