/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/01/19
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.utils.model;

import java.util.Collection;
import java.util.List;

import org.jiemamy.exception.ElementNotFoundException;
import org.jiemamy.exception.TooManyElementsException;
import org.jiemamy.exception.UnexpectedConditionError;
import org.jiemamy.model.attribute.ColumnModel;
import org.jiemamy.model.attribute.constraint.ForeignKey;
import org.jiemamy.model.attribute.constraint.LocalKeyConstraint;
import org.jiemamy.model.attribute.constraint.PrimaryKey;
import org.jiemamy.model.attribute.constraint.TableConstraint;
import org.jiemamy.model.entity.TableModel;
import org.jiemamy.utils.CollectionsUtil;

/**
 * {@link TableModel}のユーティリティクラス。
 * 
 * @author daisuke
 */
public final class TableUtil {
	
	/**
	 * カラムに設定された主キー制約を取得する。
	 * 
	 * @param tableModel 対象のテーブル
	 * @return 主キー制約
	 * @throws TooManyElementsException 複数の属性が見つかった場合
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public static PrimaryKey getColumnPrimaryKey(TableModel tableModel) {
		Collection<PrimaryKey> pks = CollectionsUtil.newArrayList();
		for (ColumnModel columnModel : tableModel.findColumns()) {
			PrimaryKey primaryKey = columnModel.getPrimaryKey();
			if (primaryKey != null) {
				pks.add(primaryKey);
			}
		}
		if (pks.size() > 1) {
			throw new TooManyElementsException(tableModel, "column primaryKey", pks);
		}
		if (pks.size() == 0) {
			return null;
		}
		return pks.iterator().next();
	}
	
	private TableUtil() {
		throw new UnexpectedConditionError("不到達ポイント");
	}
}
