/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/01/21
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.validator;

import java.util.Locale;

import org.apache.commons.lang.ArrayUtils;
import org.apache.commons.lang.Validate;

import org.jiemamy.model.RootModel;
import org.jiemamy.utils.LocalizedMessages;

/**
 * {@link Problem}の骨格実装クラス。
 * 
 * @author daisuke
 */
public abstract class AbstractProblem implements Problem {
	
	private LocalizedMessages messages = new LocalizedMessages();
	
	private Object[] arguments = ArrayUtils.EMPTY_OBJECT_ARRAY;
	
	private final String errorCode;
	

	/**
	 * インスタンスを生成する。
	 * 
	 * @param errorCode エラーコード
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	protected AbstractProblem(String errorCode) {
		Validate.notNull(errorCode);
		this.errorCode = errorCode;
	}
	
	public boolean canQuickFix() {
		return false;
	}
	
	public String getErrorCode() {
		return errorCode;
	}
	
	public String getMessage() {
		return getMessage(Locale.getDefault());
	}
	
	public String getMessage(Locale locale) {
		return messages.getMessage(locale, arguments);
	}
	
	public void quickFix(RootModel rootModel) {
		throw new CannotFixException();
	}
	
	@Override
	public String toString() {
		return errorCode + " " + getMessage();
	}
	
	/**
	 * エラーメッセージを登録する。
	 * 
	 * @param locale ロケール
	 * @param pattern エラーメッセージフォーマット
	 */
	protected void registerMessage(Locale locale, String pattern) {
		messages.register(locale, pattern);
	}
	
	/**
	 * メッセージの引数を設定する。
	 * 
	 * @param arguments 引数
	 */
	protected void setArguments(Object[] arguments) {
		this.arguments = arguments;
	}
}
