/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/01/21
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.validator.impl;

import java.util.Locale;

import org.apache.commons.lang.StringUtils;

import org.jiemamy.Jiemamy;
import org.jiemamy.model.JiemamyElement;
import org.jiemamy.model.RootModel;
import org.jiemamy.validator.AbstractProblem;
import org.jiemamy.validator.Problem;

/**
 * 全てのモデルのJiemamyコンテキストの一致を調べるバリデータ。
 * 
 * <ul>
 *   <li>全てのモデルのJiemamyコンテキストは一致していなければならない。</li>
 * </uL>
 * 
 * @author daisuke
 */
public class InstanceSpaceValidator extends AbstractTraversalValidator<Void> {
	
	private Jiemamy jiemamy;
	

	@Override
	void check(Object element, String pos) {
		if (StringUtils.equals(pos, "rootModel")) {
			jiemamy = ((RootModel) element).getJiemamy();
		}
		
		if (element instanceof JiemamyElement) {
			JiemamyElement jiemamyElement = (JiemamyElement) element;
			if (jiemamyElement.getJiemamy() != jiemamy) {
				result.add(new InstanceSpaceProblem(pos));
			}
		}
	}
	

	/**
	 * ID名が衝突していることを示す{@link Problem}オブジェクト。
	 * 
	 * @author daisuke
	 */
	static class InstanceSpaceProblem extends AbstractProblem {
		
		/**
		 * インスタンスを生成する。
		 * 
		 * @param pos 現在位置を表す文字列
		 */
		public InstanceSpaceProblem(String pos) {
			super("F0030");
			registerMessage(Locale.JAPAN, "{0}においてインスタンス空間が異なるモデルオブジェクトが存在します");
			setArguments(new Object[] {
				pos,
			});
		}
		
		public Severity getSeverity() {
			return Severity.FATAL;
		}
		
	}
	
}
