/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/01/26
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.validator.impl;

import java.util.Locale;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import org.jiemamy.ReferenceResolver;
import org.jiemamy.model.ElementReference;
import org.jiemamy.model.RootModel;
import org.jiemamy.validator.AbstractProblem;

/**
 * {@link ElementReference}が全て正常に解決できるかどうか調べるバリデータ。
 * 
 * <ul>
 *   <li>モデルに含まれる {@link ElementReference}は、そのモデルが属するインスタンス空間から取得する{@link ReferenceResolver}で全て解決できなければならない。</li>
 * </li>
 * 
 * @author daisuke
 */
public class ReferenceValidator extends AbstractTraversalValidator<Void> {
	
	private static Logger logger = LoggerFactory.getLogger(ReferenceValidator.class);
	
	private ReferenceResolver referenceResolver;
	

	@Override
	void check(Object element, String pos) {
		if (StringUtils.equals(pos, "rootModel")) {
			referenceResolver = ((RootModel) element).getJiemamy().getReferenceResolver();
		}
		if (element instanceof ElementReference<?>) {
			ElementReference<?> elementReference = (ElementReference<?>) element;
			if (referenceResolver.resolve(elementReference) == null) {
				logger.error("reference(" + pos + ") resolve error");
				result.add(new ReferenceProblem(elementReference, pos));
				
			}
		}
	}
	

	static class ReferenceProblem extends AbstractProblem {
		
		/**
		 * インスタンスを生成する。
		 * @param pos 現在位置を表す文字列
		 * @param elementReference 参照の切れた参照オブジェクト
		 */
		private ReferenceProblem(ElementReference<?> elementReference, String pos) {
			super("F0040");
			registerMessage(Locale.JAPAN, "位置{0}において{1}に対する参照が解決できません");
			setArguments(new Object[] {
				pos,
				elementReference.getReferenceId().toString()
			});
		}
		
		public Severity getSeverity() {
			return Severity.FATAL;
		}
	}
	
}
