/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/01/26
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.validator.impl;

import java.util.Collection;
import java.util.List;
import java.util.Locale;

import org.apache.commons.lang.StringUtils;

import org.jiemamy.model.RootModel;
import org.jiemamy.model.attribute.ColumnModel;
import org.jiemamy.model.entity.TableModel;
import org.jiemamy.validator.AbstractProblem;
import org.jiemamy.validator.AbstractValidator;
import org.jiemamy.validator.Problem;

/**
 * テーブルのバリデータ。
 * 
 * <ul>
 *   <li>テーブル名は必須である。</li>
 *   <li>テーブルにはカラムが1つ以上ひつようである。</li>
 * </ul>
 * 
 * @author daisuke
 */
public class TableValidator extends AbstractValidator {
	
	@Override
	public Collection<Problem> validate(RootModel rootModel) {
		Collection<Problem> result = super.validate(rootModel);
		Collection<TableModel> tableModels = rootModel.findEntities(TableModel.class);
		for (TableModel tableModel : tableModels) {
			List<ColumnModel> columns = tableModel.findColumns();
			if (columns.size() == 0) {
				result.add(new NoColumnProblem(tableModel));
			}
			if (StringUtils.isEmpty(tableModel.getName())) {
				result.add(new EmptyTableNameProblem(tableModel));
			}
		}
		return result;
	}
	

	static class EmptyTableNameProblem extends AbstractProblem {
		
		/**
		 * インスタンスを生成する。
		 * 
		 * @param tableModel テーブル名が設定されていないテーブル
		 */
		public EmptyTableNameProblem(TableModel tableModel) {
			super("E0150");
			registerMessage(Locale.JAPAN, "テーブル({0})に名前がありません");
			setArguments(new Object[] {
				tableModel.getId().toString()
			});
		}
		
		public Severity getSeverity() {
			return Severity.ERROR;
		}
		
	}
	
	static class NoColumnProblem extends AbstractProblem {
		
		/**
		 * インスタンスを生成する。
		 * 
		 * @param tableModel カラムの存在しないテーブル
		 */
		public NoColumnProblem(TableModel tableModel) {
			super("W0010");
			registerMessage(Locale.JAPAN, "テーブル{0}においてカラムが存在しません");
			setArguments(new Object[] {
				tableModel.getName()
			});
		}
		
		public Severity getSeverity() {
			return Severity.WARN;
		}
		
	}
}
